import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog - Amazon Web Services integration resource. This can be used to create and manage Datadog - Amazon Web Services integration.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Create a new Datadog - Amazon Web Services integration
 * const sandbox = new datadog.aws.Integration("sandbox", {
 *     accountId: "1234567890",
 *     accountSpecificNamespaceRules: {
 *         auto_scaling: false,
 *         opsworks: false,
 *     },
 *     excludedRegions: [
 *         "us-east-1",
 *         "us-west-2",
 *     ],
 *     filterTags: ["key:value"],
 *     hostTags: [
 *         "key:value",
 *         "key2:value2",
 *     ],
 *     roleName: "DatadogAWSIntegrationRole",
 * });
 * ```
 *
 * ## Import
 *
 * Amazon Web Services integrations can be imported using their account ID and role name separated with a colon (:), while the external_id should be passed by setting an environment variable called EXTERNAL_ID
 *
 * ```sh
 *  $ pulumi import datadog:aws/integration:Integration EXTERNAL_ID=${external_id} datadog_integration_aws.test ${account_id}:${role_name}
 * ```
 */
export declare class Integration extends pulumi.CustomResource {
    /**
     * Get an existing Integration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IntegrationState, opts?: pulumi.CustomResourceOptions): Integration;
    /**
     * Returns true if the given object is an instance of Integration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Integration;
    /**
     * Your AWS access key ID. Only required if your AWS account is a GovCloud or China account.
     */
    readonly accessKeyId: pulumi.Output<string | undefined>;
    /**
     * Your AWS Account ID without dashes.
     */
    readonly accountId: pulumi.Output<string | undefined>;
    /**
     * Enables or disables metric collection for specific AWS namespaces for this AWS account only. A list of namespaces can be found at the [available namespace rules API endpoint](https://docs.datadoghq.com/api/v1/aws-integration/#list-namespace-rules).
     */
    readonly accountSpecificNamespaceRules: pulumi.Output<{
        [key: string]: any;
    } | undefined>;
    /**
     * Whether Datadog collects cloud security posture management resources from your AWS account. This includes additional resources not covered under the general resource_collection.
     */
    readonly cspmResourceCollectionEnabled: pulumi.Output<string>;
    /**
     * An array of AWS regions to exclude from metrics collection.
     */
    readonly excludedRegions: pulumi.Output<string[] | undefined>;
    /**
     * AWS External ID. **NOTE** This provider will not be able to detect changes made to the `external_id` field from outside
     * Terraform.
     */
    readonly externalId: pulumi.Output<string>;
    /**
     * Array of EC2 tags (in the form `key:value`) defines a filter that Datadog uses when collecting metrics from EC2. Wildcards, such as `?` (for single characters) and `*` (for multiple characters) can also be used. Only hosts that match one of the defined tags will be imported into Datadog. The rest will be ignored. Host matching a given tag can also be excluded by adding `!` before the tag. e.x. `env:production,instance-type:c1.*,!region:us-east-1`.
     */
    readonly filterTags: pulumi.Output<string[] | undefined>;
    /**
     * Array of tags (in the form `key:value`) to add to all hosts and metrics reporting through this integration.
     */
    readonly hostTags: pulumi.Output<string[] | undefined>;
    /**
     * Whether Datadog collects metrics for this AWS account.
     */
    readonly metricsCollectionEnabled: pulumi.Output<string>;
    /**
     * Whether Datadog collects a standard set of resources from your AWS account.
     */
    readonly resourceCollectionEnabled: pulumi.Output<string>;
    /**
     * Your Datadog role delegation name.
     */
    readonly roleName: pulumi.Output<string | undefined>;
    /**
     * Your AWS secret access key. Only required if your AWS account is a GovCloud or China account.
     */
    readonly secretAccessKey: pulumi.Output<string | undefined>;
    /**
     * Create a Integration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: IntegrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Integration resources.
 */
export interface IntegrationState {
    /**
     * Your AWS access key ID. Only required if your AWS account is a GovCloud or China account.
     */
    accessKeyId?: pulumi.Input<string>;
    /**
     * Your AWS Account ID without dashes.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Enables or disables metric collection for specific AWS namespaces for this AWS account only. A list of namespaces can be found at the [available namespace rules API endpoint](https://docs.datadoghq.com/api/v1/aws-integration/#list-namespace-rules).
     */
    accountSpecificNamespaceRules?: pulumi.Input<{
        [key: string]: any;
    }>;
    /**
     * Whether Datadog collects cloud security posture management resources from your AWS account. This includes additional resources not covered under the general resource_collection.
     */
    cspmResourceCollectionEnabled?: pulumi.Input<string>;
    /**
     * An array of AWS regions to exclude from metrics collection.
     */
    excludedRegions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * AWS External ID. **NOTE** This provider will not be able to detect changes made to the `external_id` field from outside
     * Terraform.
     */
    externalId?: pulumi.Input<string>;
    /**
     * Array of EC2 tags (in the form `key:value`) defines a filter that Datadog uses when collecting metrics from EC2. Wildcards, such as `?` (for single characters) and `*` (for multiple characters) can also be used. Only hosts that match one of the defined tags will be imported into Datadog. The rest will be ignored. Host matching a given tag can also be excluded by adding `!` before the tag. e.x. `env:production,instance-type:c1.*,!region:us-east-1`.
     */
    filterTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Array of tags (in the form `key:value`) to add to all hosts and metrics reporting through this integration.
     */
    hostTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Whether Datadog collects metrics for this AWS account.
     */
    metricsCollectionEnabled?: pulumi.Input<string>;
    /**
     * Whether Datadog collects a standard set of resources from your AWS account.
     */
    resourceCollectionEnabled?: pulumi.Input<string>;
    /**
     * Your Datadog role delegation name.
     */
    roleName?: pulumi.Input<string>;
    /**
     * Your AWS secret access key. Only required if your AWS account is a GovCloud or China account.
     */
    secretAccessKey?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Integration resource.
 */
export interface IntegrationArgs {
    /**
     * Your AWS access key ID. Only required if your AWS account is a GovCloud or China account.
     */
    accessKeyId?: pulumi.Input<string>;
    /**
     * Your AWS Account ID without dashes.
     */
    accountId?: pulumi.Input<string>;
    /**
     * Enables or disables metric collection for specific AWS namespaces for this AWS account only. A list of namespaces can be found at the [available namespace rules API endpoint](https://docs.datadoghq.com/api/v1/aws-integration/#list-namespace-rules).
     */
    accountSpecificNamespaceRules?: pulumi.Input<{
        [key: string]: any;
    }>;
    /**
     * Whether Datadog collects cloud security posture management resources from your AWS account. This includes additional resources not covered under the general resource_collection.
     */
    cspmResourceCollectionEnabled?: pulumi.Input<string>;
    /**
     * An array of AWS regions to exclude from metrics collection.
     */
    excludedRegions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Array of EC2 tags (in the form `key:value`) defines a filter that Datadog uses when collecting metrics from EC2. Wildcards, such as `?` (for single characters) and `*` (for multiple characters) can also be used. Only hosts that match one of the defined tags will be imported into Datadog. The rest will be ignored. Host matching a given tag can also be excluded by adding `!` before the tag. e.x. `env:production,instance-type:c1.*,!region:us-east-1`.
     */
    filterTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Array of tags (in the form `key:value`) to add to all hosts and metrics reporting through this integration.
     */
    hostTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Whether Datadog collects metrics for this AWS account.
     */
    metricsCollectionEnabled?: pulumi.Input<string>;
    /**
     * Whether Datadog collects a standard set of resources from your AWS account.
     */
    resourceCollectionEnabled?: pulumi.Input<string>;
    /**
     * Your Datadog role delegation name.
     */
    roleName?: pulumi.Input<string>;
    /**
     * Your AWS secret access key. Only required if your AWS account is a GovCloud or China account.
     */
    secretAccessKey?: pulumi.Input<string>;
}
