import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog - Microsoft Azure integration resource. This can be used to create and manage the integrations.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Create a new Datadog - Microsoft Azure integration
 * const sandbox = new datadog.azure.Integration("sandbox", {
 *     clientId: "<azure_client_id>",
 *     clientSecret: "<azure_client_secret_key>",
 *     hostFilters: "examplefilter:true,example:true",
 *     tenantName: "<azure_tenant_name>",
 * });
 * ```
 *
 * ## Import
 *
 * Microsoft Azure integrations can be imported using their `tenant name` and `client` id separated with a colon (`:`).
 *
 * ```sh
 *  $ pulumi import datadog:azure/integration:Integration sandbox ${tenant_name}:${client_id}
 * ```
 */
export declare class Integration extends pulumi.CustomResource {
    /**
     * Get an existing Integration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IntegrationState, opts?: pulumi.CustomResourceOptions): Integration;
    /**
     * Returns true if the given object is an instance of Integration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Integration;
    /**
     * Silence monitors for expected Azure VM shutdowns.
     */
    readonly automute: pulumi.Output<boolean | undefined>;
    /**
     * Your Azure web application ID.
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * (Required for Initial Creation) Your Azure web application secret key.
     */
    readonly clientSecret: pulumi.Output<string>;
    /**
     * String of host tag(s) (in the form `key:value,key:value`) defines a filter that Datadog will use when collecting metrics from Azure. Limit the Azure instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog. e.x. `env:production,deploymentgroup:red`
     */
    readonly hostFilters: pulumi.Output<string | undefined>;
    /**
     * Your Azure Active Directory ID.
     */
    readonly tenantName: pulumi.Output<string>;
    /**
     * Create a Integration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntegrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Integration resources.
 */
export interface IntegrationState {
    /**
     * Silence monitors for expected Azure VM shutdowns.
     */
    automute?: pulumi.Input<boolean>;
    /**
     * Your Azure web application ID.
     */
    clientId?: pulumi.Input<string>;
    /**
     * (Required for Initial Creation) Your Azure web application secret key.
     */
    clientSecret?: pulumi.Input<string>;
    /**
     * String of host tag(s) (in the form `key:value,key:value`) defines a filter that Datadog will use when collecting metrics from Azure. Limit the Azure instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog. e.x. `env:production,deploymentgroup:red`
     */
    hostFilters?: pulumi.Input<string>;
    /**
     * Your Azure Active Directory ID.
     */
    tenantName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Integration resource.
 */
export interface IntegrationArgs {
    /**
     * Silence monitors for expected Azure VM shutdowns.
     */
    automute?: pulumi.Input<boolean>;
    /**
     * Your Azure web application ID.
     */
    clientId: pulumi.Input<string>;
    /**
     * (Required for Initial Creation) Your Azure web application secret key.
     */
    clientSecret: pulumi.Input<string>;
    /**
     * String of host tag(s) (in the form `key:value,key:value`) defines a filter that Datadog will use when collecting metrics from Azure. Limit the Azure instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog. e.x. `env:production,deploymentgroup:red`
     */
    hostFilters?: pulumi.Input<string>;
    /**
     * Your Azure Active Directory ID.
     */
    tenantName: pulumi.Input<string>;
}
