import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog downtime resource. This can be used to create and manage Datadog downtimes.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Example: downtime for all monitors
 * // Create a new daily 1700-0900 Datadog downtime for all monitors
 * const foo = new datadog.Downtime("foo", {
 *     end: 1483365600,
 *     recurrence: {
 *         period: 1,
 *         type: "days",
 *     },
 *     scopes: ["*"],
 *     start: 1483308000,
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/downtime:Downtime bytes_received_localhost 2081
 * ```
 */
export declare class Downtime extends pulumi.CustomResource {
    /**
     * Get an existing Downtime resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DowntimeState, opts?: pulumi.CustomResourceOptions): Downtime;
    /**
     * Returns true if the given object is an instance of Downtime.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Downtime;
    /**
     * When true indicates this downtime is being actively applied
     */
    readonly active: pulumi.Output<boolean>;
    /**
     * The id corresponding to the downtime object definition of the active child for the original parent recurring downtime. This field will only exist on recurring downtimes.
     */
    readonly activeChildId: pulumi.Output<number>;
    /**
     * When true indicates this downtime is not being applied
     */
    readonly disabled: pulumi.Output<boolean>;
    /**
     * Optionally specify an end date when this downtime should expire. Accepts a Unix timestamp in UTC.
     */
    readonly end: pulumi.Output<number | undefined>;
    /**
     * String representing date and time to end the downtime in RFC3339 format.
     */
    readonly endDate: pulumi.Output<string | undefined>;
    /**
     * An optional message to provide when creating the downtime, can include notification handles
     */
    readonly message: pulumi.Output<string | undefined>;
    /**
     * When specified, this downtime will only apply to this monitor
     */
    readonly monitorId: pulumi.Output<number | undefined>;
    /**
     * A list of monitor tags (up to 32) to base the scheduled downtime on. Only monitors that have all selected tags are silenced
     */
    readonly monitorTags: pulumi.Output<string[] | undefined>;
    /**
     * When true the first recovery notification during the downtime will be muted
     */
    readonly muteFirstRecoveryNotification: pulumi.Output<boolean | undefined>;
    /**
     * Optional recurring schedule for this downtime
     */
    readonly recurrence: pulumi.Output<outputs.DowntimeRecurrence | undefined>;
    /**
     * specify the group scope to which this downtime applies. For everything use '*'
     */
    readonly scopes: pulumi.Output<string[]>;
    /**
     * Specify when this downtime should start. Accepts a Unix timestamp in UTC.
     */
    readonly start: pulumi.Output<number | undefined>;
    /**
     * String representing date and time to start the downtime in RFC3339 format.
     */
    readonly startDate: pulumi.Output<string | undefined>;
    /**
     * The timezone for the downtime, default UTC. Follows IANA timezone database identifiers.
     */
    readonly timezone: pulumi.Output<string | undefined>;
    /**
     * Create a Downtime resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DowntimeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Downtime resources.
 */
export interface DowntimeState {
    /**
     * When true indicates this downtime is being actively applied
     */
    active?: pulumi.Input<boolean>;
    /**
     * The id corresponding to the downtime object definition of the active child for the original parent recurring downtime. This field will only exist on recurring downtimes.
     */
    activeChildId?: pulumi.Input<number>;
    /**
     * When true indicates this downtime is not being applied
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * Optionally specify an end date when this downtime should expire. Accepts a Unix timestamp in UTC.
     */
    end?: pulumi.Input<number>;
    /**
     * String representing date and time to end the downtime in RFC3339 format.
     */
    endDate?: pulumi.Input<string>;
    /**
     * An optional message to provide when creating the downtime, can include notification handles
     */
    message?: pulumi.Input<string>;
    /**
     * When specified, this downtime will only apply to this monitor
     */
    monitorId?: pulumi.Input<number>;
    /**
     * A list of monitor tags (up to 32) to base the scheduled downtime on. Only monitors that have all selected tags are silenced
     */
    monitorTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * When true the first recovery notification during the downtime will be muted
     */
    muteFirstRecoveryNotification?: pulumi.Input<boolean>;
    /**
     * Optional recurring schedule for this downtime
     */
    recurrence?: pulumi.Input<inputs.DowntimeRecurrence>;
    /**
     * specify the group scope to which this downtime applies. For everything use '*'
     */
    scopes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Specify when this downtime should start. Accepts a Unix timestamp in UTC.
     */
    start?: pulumi.Input<number>;
    /**
     * String representing date and time to start the downtime in RFC3339 format.
     */
    startDate?: pulumi.Input<string>;
    /**
     * The timezone for the downtime, default UTC. Follows IANA timezone database identifiers.
     */
    timezone?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Downtime resource.
 */
export interface DowntimeArgs {
    /**
     * Optionally specify an end date when this downtime should expire. Accepts a Unix timestamp in UTC.
     */
    end?: pulumi.Input<number>;
    /**
     * String representing date and time to end the downtime in RFC3339 format.
     */
    endDate?: pulumi.Input<string>;
    /**
     * An optional message to provide when creating the downtime, can include notification handles
     */
    message?: pulumi.Input<string>;
    /**
     * When specified, this downtime will only apply to this monitor
     */
    monitorId?: pulumi.Input<number>;
    /**
     * A list of monitor tags (up to 32) to base the scheduled downtime on. Only monitors that have all selected tags are silenced
     */
    monitorTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * When true the first recovery notification during the downtime will be muted
     */
    muteFirstRecoveryNotification?: pulumi.Input<boolean>;
    /**
     * Optional recurring schedule for this downtime
     */
    recurrence?: pulumi.Input<inputs.DowntimeRecurrence>;
    /**
     * specify the group scope to which this downtime applies. For everything use '*'
     */
    scopes: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Specify when this downtime should start. Accepts a Unix timestamp in UTC.
     */
    start?: pulumi.Input<number>;
    /**
     * String representing date and time to start the downtime in RFC3339 format.
     */
    startDate?: pulumi.Input<string>;
    /**
     * The timezone for the downtime, default UTC. Follows IANA timezone database identifiers.
     */
    timezone?: pulumi.Input<string>;
}
