import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog Logs Archive API resource, which is used to create and manage Datadog logs archives.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const myS3Archive = new datadog.LogsArchive("myS3Archive", {
 *     name: "my s3 archive",
 *     query: "service:myservice",
 *     s3Archive: {
 *         accountId: "001234567888",
 *         bucket: "my-bucket",
 *         path: "/path/foo",
 *         roleName: "my-role-name",
 *     },
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/logsArchive:LogsArchive my_s3_archive 1Aabc2_dfQPLnXy3HlfK4hi
 * ```
 */
export declare class LogsArchive extends pulumi.CustomResource {
    /**
     * Get an existing LogsArchive resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LogsArchiveState, opts?: pulumi.CustomResourceOptions): LogsArchive;
    /**
     * Returns true if the given object is an instance of LogsArchive.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogsArchive;
    /**
     * Definition of an azure archive.
     */
    readonly azureArchive: pulumi.Output<outputs.LogsArchiveAzureArchive | undefined>;
    /**
     * Definition of a GCS archive.
     */
    readonly gcsArchive: pulumi.Output<outputs.LogsArchiveGcsArchive | undefined>;
    /**
     * To store the tags in the archive, set the value `true`. If it is set to `false`, the tags will be dropped when the logs are sent to the archive.
     */
    readonly includeTags: pulumi.Output<boolean | undefined>;
    /**
     * Your archive name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The archive query/filter. Logs matching this query are included in the archive.
     */
    readonly query: pulumi.Output<string>;
    /**
     * To limit the rehydration scan size for the archive, set a value in GB.
     */
    readonly rehydrationMaxScanSizeInGb: pulumi.Output<number | undefined>;
    /**
     * An array of tags to add to rehydrated logs from an archive.
     */
    readonly rehydrationTags: pulumi.Output<string[] | undefined>;
    /**
     * Definition of an s3 archive.
     */
    readonly s3Archive: pulumi.Output<outputs.LogsArchiveS3Archive | undefined>;
    /**
     * Create a LogsArchive resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogsArchiveArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LogsArchive resources.
 */
export interface LogsArchiveState {
    /**
     * Definition of an azure archive.
     */
    azureArchive?: pulumi.Input<inputs.LogsArchiveAzureArchive>;
    /**
     * Definition of a GCS archive.
     */
    gcsArchive?: pulumi.Input<inputs.LogsArchiveGcsArchive>;
    /**
     * To store the tags in the archive, set the value `true`. If it is set to `false`, the tags will be dropped when the logs are sent to the archive.
     */
    includeTags?: pulumi.Input<boolean>;
    /**
     * Your archive name.
     */
    name?: pulumi.Input<string>;
    /**
     * The archive query/filter. Logs matching this query are included in the archive.
     */
    query?: pulumi.Input<string>;
    /**
     * To limit the rehydration scan size for the archive, set a value in GB.
     */
    rehydrationMaxScanSizeInGb?: pulumi.Input<number>;
    /**
     * An array of tags to add to rehydrated logs from an archive.
     */
    rehydrationTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Definition of an s3 archive.
     */
    s3Archive?: pulumi.Input<inputs.LogsArchiveS3Archive>;
}
/**
 * The set of arguments for constructing a LogsArchive resource.
 */
export interface LogsArchiveArgs {
    /**
     * Definition of an azure archive.
     */
    azureArchive?: pulumi.Input<inputs.LogsArchiveAzureArchive>;
    /**
     * Definition of a GCS archive.
     */
    gcsArchive?: pulumi.Input<inputs.LogsArchiveGcsArchive>;
    /**
     * To store the tags in the archive, set the value `true`. If it is set to `false`, the tags will be dropped when the logs are sent to the archive.
     */
    includeTags?: pulumi.Input<boolean>;
    /**
     * Your archive name.
     */
    name: pulumi.Input<string>;
    /**
     * The archive query/filter. Logs matching this query are included in the archive.
     */
    query: pulumi.Input<string>;
    /**
     * To limit the rehydration scan size for the archive, set a value in GB.
     */
    rehydrationMaxScanSizeInGb?: pulumi.Input<number>;
    /**
     * An array of tags to add to rehydrated logs from an archive.
     */
    rehydrationTags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Definition of an s3 archive.
     */
    s3Archive?: pulumi.Input<inputs.LogsArchiveS3Archive>;
}
