import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog monitor resource. This can be used to create and manage Datadog monitors.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = new datadog.Monitor("foo", {
 *     escalationMessage: "Escalation message @pagerduty",
 *     includeTags: true,
 *     message: "Monitor triggered. Notify: @hipchat-channel",
 *     monitorThresholds: {
 *         critical: "4",
 *         warning: "2",
 *     },
 *     name: "Name for monitor foo",
 *     query: "avg(last_1h):avg:aws.ec2.cpu{environment:foo,host:foo} by {host} > 4",
 *     tags: [
 *         "foo:bar",
 *         "team:fooBar",
 *     ],
 *     type: "metric alert",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/monitor:Monitor bytes_received_localhost 2081
 * ```
 */
export declare class Monitor extends pulumi.CustomResource {
    /**
     * Get an existing Monitor resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MonitorState, opts?: pulumi.CustomResourceOptions): Monitor;
    /**
     * Returns true if the given object is an instance of Monitor.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Monitor;
    /**
     * A boolean indicating whether or not to include a list of log values which triggered the alert. This is only used by log
     * monitors. Defaults to `false`.
     */
    readonly enableLogsSample: pulumi.Output<boolean | undefined>;
    /**
     * Whether or not a list of samples which triggered the alert is included. This is only used by CI Test and Pipeline
     * monitors.
     */
    readonly enableSamples: pulumi.Output<boolean>;
    /**
     * A message to include with a re-notification. Supports the `@username` notification allowed elsewhere.
     */
    readonly escalationMessage: pulumi.Output<string | undefined>;
    /**
     * (Only applies to metric alert) Time (in seconds) to delay evaluation, as a non-negative integer. For example, if the
     * value is set to `300` (5min), the `timeframe` is set to `last_5m` and the time is 7:00, the monitor will evaluate data
     * from 6:50 to 6:55. This is useful for AWS CloudWatch and other backfilled metrics to ensure the monitor will always have
     * data during evaluation.
     */
    readonly evaluationDelay: pulumi.Output<number>;
    /**
     * A boolean indicating whether this monitor can be deleted even if it’s referenced by other resources (e.g. SLO,
     * composite monitor).
     */
    readonly forceDelete: pulumi.Output<boolean | undefined>;
    /**
     * The time span after which groups with missing data are dropped from the monitor state. The minimum value is one hour,
     * and the maximum value is 72 hours. Example values are: 60m, 1h, and 2d. This option is only available for APM Trace
     * Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors.
     */
    readonly groupRetentionDuration: pulumi.Output<string | undefined>;
    /**
     * Whether or not to trigger one alert if any source breaches a threshold. This is only used by log monitors. Defaults to
     * `false`.
     */
    readonly groupbySimpleMonitor: pulumi.Output<boolean | undefined>;
    /**
     * A boolean indicating whether notifications from this monitor automatically insert its triggering tags into the title.
     * Defaults to `true`.
     */
    readonly includeTags: pulumi.Output<boolean | undefined>;
    /**
     * A boolean indicating whether changes to this monitor should be restricted to the creator or admins. Defaults to `false`.
     *
     * @deprecated Use `restricted_roles`.
     */
    readonly locked: pulumi.Output<boolean | undefined>;
    /**
     * A message to include with notifications for this monitor.
     */
    readonly message: pulumi.Output<string>;
    /**
     * A mapping containing `recovery_window` and `trigger_window` values, e.g. `last_15m` . Can only be used for, and are
     * required for, anomaly monitors.
     */
    readonly monitorThresholdWindows: pulumi.Output<outputs.MonitorMonitorThresholdWindows | undefined>;
    /**
     * Alert thresholds of the monitor.
     */
    readonly monitorThresholds: pulumi.Output<outputs.MonitorMonitorThresholds | undefined>;
    /**
     * Name of Datadog monitor.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The time (in seconds) to skip evaluations for new groups. `new_group_delay` overrides `new_host_delay` if it is set to a
     * nonzero value.
     */
    readonly newGroupDelay: pulumi.Output<number | undefined>;
    /**
     * **Deprecated**. See `new_group_delay`. Time (in seconds) to allow a host to boot and applications to fully start before
     * starting the evaluation of monitor results. Should be a non-negative integer. This value is ignored for simple monitors
     * and monitors not grouped by host. Defaults to `300`. The only case when this should be used is to override the default
     * and set `new_host_delay` to zero for monitors grouped by host.
     *
     * @deprecated Use `new_group_delay` except when setting `new_host_delay` to zero.
     */
    readonly newHostDelay: pulumi.Output<number | undefined>;
    /**
     * The number of minutes before a monitor will notify when data stops reporting. Provider defaults to 10 minutes. We
     * recommend at least 2x the monitor timeframe for metric alerts or 2 minutes for service checks.
     */
    readonly noDataTimeframe: pulumi.Output<number | undefined>;
    /**
     * Toggles the display of additional content sent in the monitor notification.
     */
    readonly notificationPresetName: pulumi.Output<string | undefined>;
    /**
     * A boolean indicating whether tagged users will be notified on changes to this monitor. Defaults to `false`.
     */
    readonly notifyAudit: pulumi.Output<boolean | undefined>;
    /**
     * Controls what granularity a monitor alerts on. Only available for monitors with groupings. For instance, a monitor
     * grouped by `cluster`, `namespace`, and `pod` can be configured to only notify on each new `cluster` violating the alert
     * conditions by setting `notify_by` to `['cluster']`. Tags mentioned in `notify_by` must be a subset of the grouping tags
     * in the query. For example, a query grouped by `cluster` and `namespace` cannot notify on `region`. Setting `notify_by`
     * to `[*]` configures the monitor to notify as a simple-alert. **NOTE:** Currently in private beta. To request access,
     * contact Support at support@datadoghq.com
     */
    readonly notifyBies: pulumi.Output<string[] | undefined>;
    /**
     * A boolean indicating whether this monitor will notify when data stops reporting. Defaults to `false`.
     */
    readonly notifyNoData: pulumi.Output<boolean | undefined>;
    /**
     * Controls how groups or monitors are treated if an evaluation does not return any data points. The default option results
     * in different behavior depending on the monitor query type. For monitors using `Count` queries, an empty monitor
     * evaluation is treated as 0 and is compared to the threshold conditions. For monitors using any query type other than
     * `Count`, for example `Gauge`, `Measure`, or `Rate`, the monitor shows the last known status. This option is only
     * available for APM Trace Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors. Valid values are:
     * `show_no_data`, `show_and_notify_no_data`, `resolve`, and `default`.
     */
    readonly onMissingData: pulumi.Output<string | undefined>;
    /**
     * Integer from 1 (high) to 5 (low) indicating alert severity.
     */
    readonly priority: pulumi.Output<number | undefined>;
    /**
     * The monitor query to notify on. Note this is not the same query you see in the UI and the syntax is different depending
     * on the monitor type, please see the [API Reference](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor) for
     * details. `terraform plan` will validate query contents unless `validate` is set to `false`. **Note:** APM latency data
     * is now available as Distribution Metrics. Existing monitors have been migrated automatically but all terraformed
     * monitors can still use the existing metrics. We strongly recommend updating monitor definitions to query the new
     * metrics. To learn more, or to see examples of how to update your terraform definitions to utilize the new distribution
     * metrics, see the [detailed doc](https://docs.datadoghq.com/tracing/guide/ddsketch_trace_metrics/).
     */
    readonly query: pulumi.Output<string>;
    /**
     * The number of minutes after the last notification before a monitor will re-notify on the current status. It will only
     * re-notify if it's not resolved.
     */
    readonly renotifyInterval: pulumi.Output<number | undefined>;
    /**
     * The number of re-notification messages that should be sent on the current status.
     */
    readonly renotifyOccurrences: pulumi.Output<number | undefined>;
    /**
     * The types of statuses for which re-notification messages should be sent.
     */
    readonly renotifyStatuses: pulumi.Output<string[] | undefined>;
    /**
     * A boolean indicating whether this monitor needs a full window of data before it's evaluated. We highly recommend you set
     * this to `false` for sparse metrics, otherwise some evaluations will be skipped. Default: `true` for `on average`, `at
     * all times` and `in total` aggregation. `false` otherwise.
     */
    readonly requireFullWindow: pulumi.Output<boolean | undefined>;
    /**
     * A list of unique role identifiers to define which roles are allowed to edit the monitor. Editing a monitor includes any
     * updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. Roles unique
     * identifiers can be pulled from the [Roles API](https://docs.datadoghq.com/api/latest/roles/#list-roles) in the `data.id`
     * field.
     */
    readonly restrictedRoles: pulumi.Output<string[] | undefined>;
    /**
     * Configuration options for scheduling.
     */
    readonly schedulingOptions: pulumi.Output<outputs.MonitorSchedulingOption[] | undefined>;
    /**
     * A list of tags to associate with your monitor. This can help you categorize and filter monitors in the manage monitors
     * page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * The number of hours of the monitor not reporting data before it automatically resolves from a triggered state. The
     * minimum allowed value is 0 hours. The maximum allowed value is 24 hours.
     */
    readonly timeoutH: pulumi.Output<number | undefined>;
    /**
     * The type of the monitor. The mapping from these types to the types found in the Datadog Web UI can be found in the
     * Datadog API [documentation page](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor). Note: The monitor type
     * cannot be changed after a monitor is created.
     */
    readonly type: pulumi.Output<string>;
    /**
     * If set to `false`, skip the validation call done during plan.
     */
    readonly validate: pulumi.Output<boolean | undefined>;
    readonly variables: pulumi.Output<outputs.MonitorVariables | undefined>;
    /**
     * Create a Monitor resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MonitorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Monitor resources.
 */
export interface MonitorState {
    /**
     * A boolean indicating whether or not to include a list of log values which triggered the alert. This is only used by log
     * monitors. Defaults to `false`.
     */
    enableLogsSample?: pulumi.Input<boolean>;
    /**
     * Whether or not a list of samples which triggered the alert is included. This is only used by CI Test and Pipeline
     * monitors.
     */
    enableSamples?: pulumi.Input<boolean>;
    /**
     * A message to include with a re-notification. Supports the `@username` notification allowed elsewhere.
     */
    escalationMessage?: pulumi.Input<string>;
    /**
     * (Only applies to metric alert) Time (in seconds) to delay evaluation, as a non-negative integer. For example, if the
     * value is set to `300` (5min), the `timeframe` is set to `last_5m` and the time is 7:00, the monitor will evaluate data
     * from 6:50 to 6:55. This is useful for AWS CloudWatch and other backfilled metrics to ensure the monitor will always have
     * data during evaluation.
     */
    evaluationDelay?: pulumi.Input<number>;
    /**
     * A boolean indicating whether this monitor can be deleted even if it’s referenced by other resources (e.g. SLO,
     * composite monitor).
     */
    forceDelete?: pulumi.Input<boolean>;
    /**
     * The time span after which groups with missing data are dropped from the monitor state. The minimum value is one hour,
     * and the maximum value is 72 hours. Example values are: 60m, 1h, and 2d. This option is only available for APM Trace
     * Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors.
     */
    groupRetentionDuration?: pulumi.Input<string>;
    /**
     * Whether or not to trigger one alert if any source breaches a threshold. This is only used by log monitors. Defaults to
     * `false`.
     */
    groupbySimpleMonitor?: pulumi.Input<boolean>;
    /**
     * A boolean indicating whether notifications from this monitor automatically insert its triggering tags into the title.
     * Defaults to `true`.
     */
    includeTags?: pulumi.Input<boolean>;
    /**
     * A boolean indicating whether changes to this monitor should be restricted to the creator or admins. Defaults to `false`.
     *
     * @deprecated Use `restricted_roles`.
     */
    locked?: pulumi.Input<boolean>;
    /**
     * A message to include with notifications for this monitor.
     */
    message?: pulumi.Input<string>;
    /**
     * A mapping containing `recovery_window` and `trigger_window` values, e.g. `last_15m` . Can only be used for, and are
     * required for, anomaly monitors.
     */
    monitorThresholdWindows?: pulumi.Input<inputs.MonitorMonitorThresholdWindows>;
    /**
     * Alert thresholds of the monitor.
     */
    monitorThresholds?: pulumi.Input<inputs.MonitorMonitorThresholds>;
    /**
     * Name of Datadog monitor.
     */
    name?: pulumi.Input<string>;
    /**
     * The time (in seconds) to skip evaluations for new groups. `new_group_delay` overrides `new_host_delay` if it is set to a
     * nonzero value.
     */
    newGroupDelay?: pulumi.Input<number>;
    /**
     * **Deprecated**. See `new_group_delay`. Time (in seconds) to allow a host to boot and applications to fully start before
     * starting the evaluation of monitor results. Should be a non-negative integer. This value is ignored for simple monitors
     * and monitors not grouped by host. Defaults to `300`. The only case when this should be used is to override the default
     * and set `new_host_delay` to zero for monitors grouped by host.
     *
     * @deprecated Use `new_group_delay` except when setting `new_host_delay` to zero.
     */
    newHostDelay?: pulumi.Input<number>;
    /**
     * The number of minutes before a monitor will notify when data stops reporting. Provider defaults to 10 minutes. We
     * recommend at least 2x the monitor timeframe for metric alerts or 2 minutes for service checks.
     */
    noDataTimeframe?: pulumi.Input<number>;
    /**
     * Toggles the display of additional content sent in the monitor notification.
     */
    notificationPresetName?: pulumi.Input<string>;
    /**
     * A boolean indicating whether tagged users will be notified on changes to this monitor. Defaults to `false`.
     */
    notifyAudit?: pulumi.Input<boolean>;
    /**
     * Controls what granularity a monitor alerts on. Only available for monitors with groupings. For instance, a monitor
     * grouped by `cluster`, `namespace`, and `pod` can be configured to only notify on each new `cluster` violating the alert
     * conditions by setting `notify_by` to `['cluster']`. Tags mentioned in `notify_by` must be a subset of the grouping tags
     * in the query. For example, a query grouped by `cluster` and `namespace` cannot notify on `region`. Setting `notify_by`
     * to `[*]` configures the monitor to notify as a simple-alert. **NOTE:** Currently in private beta. To request access,
     * contact Support at support@datadoghq.com
     */
    notifyBies?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A boolean indicating whether this monitor will notify when data stops reporting. Defaults to `false`.
     */
    notifyNoData?: pulumi.Input<boolean>;
    /**
     * Controls how groups or monitors are treated if an evaluation does not return any data points. The default option results
     * in different behavior depending on the monitor query type. For monitors using `Count` queries, an empty monitor
     * evaluation is treated as 0 and is compared to the threshold conditions. For monitors using any query type other than
     * `Count`, for example `Gauge`, `Measure`, or `Rate`, the monitor shows the last known status. This option is only
     * available for APM Trace Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors. Valid values are:
     * `show_no_data`, `show_and_notify_no_data`, `resolve`, and `default`.
     */
    onMissingData?: pulumi.Input<string>;
    /**
     * Integer from 1 (high) to 5 (low) indicating alert severity.
     */
    priority?: pulumi.Input<number>;
    /**
     * The monitor query to notify on. Note this is not the same query you see in the UI and the syntax is different depending
     * on the monitor type, please see the [API Reference](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor) for
     * details. `terraform plan` will validate query contents unless `validate` is set to `false`. **Note:** APM latency data
     * is now available as Distribution Metrics. Existing monitors have been migrated automatically but all terraformed
     * monitors can still use the existing metrics. We strongly recommend updating monitor definitions to query the new
     * metrics. To learn more, or to see examples of how to update your terraform definitions to utilize the new distribution
     * metrics, see the [detailed doc](https://docs.datadoghq.com/tracing/guide/ddsketch_trace_metrics/).
     */
    query?: pulumi.Input<string>;
    /**
     * The number of minutes after the last notification before a monitor will re-notify on the current status. It will only
     * re-notify if it's not resolved.
     */
    renotifyInterval?: pulumi.Input<number>;
    /**
     * The number of re-notification messages that should be sent on the current status.
     */
    renotifyOccurrences?: pulumi.Input<number>;
    /**
     * The types of statuses for which re-notification messages should be sent.
     */
    renotifyStatuses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A boolean indicating whether this monitor needs a full window of data before it's evaluated. We highly recommend you set
     * this to `false` for sparse metrics, otherwise some evaluations will be skipped. Default: `true` for `on average`, `at
     * all times` and `in total` aggregation. `false` otherwise.
     */
    requireFullWindow?: pulumi.Input<boolean>;
    /**
     * A list of unique role identifiers to define which roles are allowed to edit the monitor. Editing a monitor includes any
     * updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. Roles unique
     * identifiers can be pulled from the [Roles API](https://docs.datadoghq.com/api/latest/roles/#list-roles) in the `data.id`
     * field.
     */
    restrictedRoles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Configuration options for scheduling.
     */
    schedulingOptions?: pulumi.Input<pulumi.Input<inputs.MonitorSchedulingOption>[]>;
    /**
     * A list of tags to associate with your monitor. This can help you categorize and filter monitors in the manage monitors
     * page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The number of hours of the monitor not reporting data before it automatically resolves from a triggered state. The
     * minimum allowed value is 0 hours. The maximum allowed value is 24 hours.
     */
    timeoutH?: pulumi.Input<number>;
    /**
     * The type of the monitor. The mapping from these types to the types found in the Datadog Web UI can be found in the
     * Datadog API [documentation page](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor). Note: The monitor type
     * cannot be changed after a monitor is created.
     */
    type?: pulumi.Input<string>;
    /**
     * If set to `false`, skip the validation call done during plan.
     */
    validate?: pulumi.Input<boolean>;
    variables?: pulumi.Input<inputs.MonitorVariables>;
}
/**
 * The set of arguments for constructing a Monitor resource.
 */
export interface MonitorArgs {
    /**
     * A boolean indicating whether or not to include a list of log values which triggered the alert. This is only used by log
     * monitors. Defaults to `false`.
     */
    enableLogsSample?: pulumi.Input<boolean>;
    /**
     * A message to include with a re-notification. Supports the `@username` notification allowed elsewhere.
     */
    escalationMessage?: pulumi.Input<string>;
    /**
     * (Only applies to metric alert) Time (in seconds) to delay evaluation, as a non-negative integer. For example, if the
     * value is set to `300` (5min), the `timeframe` is set to `last_5m` and the time is 7:00, the monitor will evaluate data
     * from 6:50 to 6:55. This is useful for AWS CloudWatch and other backfilled metrics to ensure the monitor will always have
     * data during evaluation.
     */
    evaluationDelay?: pulumi.Input<number>;
    /**
     * A boolean indicating whether this monitor can be deleted even if it’s referenced by other resources (e.g. SLO,
     * composite monitor).
     */
    forceDelete?: pulumi.Input<boolean>;
    /**
     * The time span after which groups with missing data are dropped from the monitor state. The minimum value is one hour,
     * and the maximum value is 72 hours. Example values are: 60m, 1h, and 2d. This option is only available for APM Trace
     * Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors.
     */
    groupRetentionDuration?: pulumi.Input<string>;
    /**
     * Whether or not to trigger one alert if any source breaches a threshold. This is only used by log monitors. Defaults to
     * `false`.
     */
    groupbySimpleMonitor?: pulumi.Input<boolean>;
    /**
     * A boolean indicating whether notifications from this monitor automatically insert its triggering tags into the title.
     * Defaults to `true`.
     */
    includeTags?: pulumi.Input<boolean>;
    /**
     * A boolean indicating whether changes to this monitor should be restricted to the creator or admins. Defaults to `false`.
     *
     * @deprecated Use `restricted_roles`.
     */
    locked?: pulumi.Input<boolean>;
    /**
     * A message to include with notifications for this monitor.
     */
    message: pulumi.Input<string>;
    /**
     * A mapping containing `recovery_window` and `trigger_window` values, e.g. `last_15m` . Can only be used for, and are
     * required for, anomaly monitors.
     */
    monitorThresholdWindows?: pulumi.Input<inputs.MonitorMonitorThresholdWindows>;
    /**
     * Alert thresholds of the monitor.
     */
    monitorThresholds?: pulumi.Input<inputs.MonitorMonitorThresholds>;
    /**
     * Name of Datadog monitor.
     */
    name: pulumi.Input<string>;
    /**
     * The time (in seconds) to skip evaluations for new groups. `new_group_delay` overrides `new_host_delay` if it is set to a
     * nonzero value.
     */
    newGroupDelay?: pulumi.Input<number>;
    /**
     * **Deprecated**. See `new_group_delay`. Time (in seconds) to allow a host to boot and applications to fully start before
     * starting the evaluation of monitor results. Should be a non-negative integer. This value is ignored for simple monitors
     * and monitors not grouped by host. Defaults to `300`. The only case when this should be used is to override the default
     * and set `new_host_delay` to zero for monitors grouped by host.
     *
     * @deprecated Use `new_group_delay` except when setting `new_host_delay` to zero.
     */
    newHostDelay?: pulumi.Input<number>;
    /**
     * The number of minutes before a monitor will notify when data stops reporting. Provider defaults to 10 minutes. We
     * recommend at least 2x the monitor timeframe for metric alerts or 2 minutes for service checks.
     */
    noDataTimeframe?: pulumi.Input<number>;
    /**
     * Toggles the display of additional content sent in the monitor notification.
     */
    notificationPresetName?: pulumi.Input<string>;
    /**
     * A boolean indicating whether tagged users will be notified on changes to this monitor. Defaults to `false`.
     */
    notifyAudit?: pulumi.Input<boolean>;
    /**
     * Controls what granularity a monitor alerts on. Only available for monitors with groupings. For instance, a monitor
     * grouped by `cluster`, `namespace`, and `pod` can be configured to only notify on each new `cluster` violating the alert
     * conditions by setting `notify_by` to `['cluster']`. Tags mentioned in `notify_by` must be a subset of the grouping tags
     * in the query. For example, a query grouped by `cluster` and `namespace` cannot notify on `region`. Setting `notify_by`
     * to `[*]` configures the monitor to notify as a simple-alert. **NOTE:** Currently in private beta. To request access,
     * contact Support at support@datadoghq.com
     */
    notifyBies?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A boolean indicating whether this monitor will notify when data stops reporting. Defaults to `false`.
     */
    notifyNoData?: pulumi.Input<boolean>;
    /**
     * Controls how groups or monitors are treated if an evaluation does not return any data points. The default option results
     * in different behavior depending on the monitor query type. For monitors using `Count` queries, an empty monitor
     * evaluation is treated as 0 and is compared to the threshold conditions. For monitors using any query type other than
     * `Count`, for example `Gauge`, `Measure`, or `Rate`, the monitor shows the last known status. This option is only
     * available for APM Trace Analytics, Audit Trail, CI, Error Tracking, Event, Logs, and RUM monitors. Valid values are:
     * `show_no_data`, `show_and_notify_no_data`, `resolve`, and `default`.
     */
    onMissingData?: pulumi.Input<string>;
    /**
     * Integer from 1 (high) to 5 (low) indicating alert severity.
     */
    priority?: pulumi.Input<number>;
    /**
     * The monitor query to notify on. Note this is not the same query you see in the UI and the syntax is different depending
     * on the monitor type, please see the [API Reference](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor) for
     * details. `terraform plan` will validate query contents unless `validate` is set to `false`. **Note:** APM latency data
     * is now available as Distribution Metrics. Existing monitors have been migrated automatically but all terraformed
     * monitors can still use the existing metrics. We strongly recommend updating monitor definitions to query the new
     * metrics. To learn more, or to see examples of how to update your terraform definitions to utilize the new distribution
     * metrics, see the [detailed doc](https://docs.datadoghq.com/tracing/guide/ddsketch_trace_metrics/).
     */
    query: pulumi.Input<string>;
    /**
     * The number of minutes after the last notification before a monitor will re-notify on the current status. It will only
     * re-notify if it's not resolved.
     */
    renotifyInterval?: pulumi.Input<number>;
    /**
     * The number of re-notification messages that should be sent on the current status.
     */
    renotifyOccurrences?: pulumi.Input<number>;
    /**
     * The types of statuses for which re-notification messages should be sent.
     */
    renotifyStatuses?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A boolean indicating whether this monitor needs a full window of data before it's evaluated. We highly recommend you set
     * this to `false` for sparse metrics, otherwise some evaluations will be skipped. Default: `true` for `on average`, `at
     * all times` and `in total` aggregation. `false` otherwise.
     */
    requireFullWindow?: pulumi.Input<boolean>;
    /**
     * A list of unique role identifiers to define which roles are allowed to edit the monitor. Editing a monitor includes any
     * updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. Roles unique
     * identifiers can be pulled from the [Roles API](https://docs.datadoghq.com/api/latest/roles/#list-roles) in the `data.id`
     * field.
     */
    restrictedRoles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Configuration options for scheduling.
     */
    schedulingOptions?: pulumi.Input<pulumi.Input<inputs.MonitorSchedulingOption>[]>;
    /**
     * A list of tags to associate with your monitor. This can help you categorize and filter monitors in the manage monitors
     * page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The number of hours of the monitor not reporting data before it automatically resolves from a triggered state. The
     * minimum allowed value is 0 hours. The maximum allowed value is 24 hours.
     */
    timeoutH?: pulumi.Input<number>;
    /**
     * The type of the monitor. The mapping from these types to the types found in the Datadog Web UI can be found in the
     * Datadog API [documentation page](https://docs.datadoghq.com/api/v1/monitors/#create-a-monitor). Note: The monitor type
     * cannot be changed after a monitor is created.
     */
    type: pulumi.Input<string>;
    /**
     * If set to `false`, skip the validation call done during plan.
     */
    validate?: pulumi.Input<boolean>;
    variables?: pulumi.Input<inputs.MonitorVariables>;
}
