import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog Security Monitoring Rule API resource. This can be used to create and manage Datadog security monitoring rules. To change settings for a default rule use `datadogSecurityDefaultRule` instead.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const myrule = new datadog.SecurityMonitoringRule("myrule", {
 *     cases: [{
 *         condition: "errors > 3 && warnings > 10",
 *         notifications: ["@user"],
 *         status: "high",
 *     }],
 *     enabled: true,
 *     message: "The rule has triggered.",
 *     name: "My rule",
 *     options: {
 *         evaluationWindow: 300,
 *         keepAlive: 600,
 *         maxSignalDuration: 900,
 *     },
 *     queries: [
 *         {
 *             aggregation: "count",
 *             groupByFields: ["host"],
 *             name: "errors",
 *             query: "status:error",
 *         },
 *         {
 *             aggregation: "count",
 *             groupByFields: ["host"],
 *             name: "warnings",
 *             query: "status:warning",
 *         },
 *     ],
 *     tags: ["type:dos"],
 * });
 * ```
 *
 * ## Import
 *
 * Security monitoring rules can be imported using ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/securityMonitoringRule:SecurityMonitoringRule my_rule m0o-hto-lkb
 * ```
 */
export declare class SecurityMonitoringRule extends pulumi.CustomResource {
    /**
     * Get an existing SecurityMonitoringRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SecurityMonitoringRuleState, opts?: pulumi.CustomResourceOptions): SecurityMonitoringRule;
    /**
     * Returns true if the given object is an instance of SecurityMonitoringRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityMonitoringRule;
    /**
     * Cases for generating signals.
     */
    readonly cases: pulumi.Output<outputs.SecurityMonitoringRuleCase[]>;
    /**
     * Whether the rule is enabled.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * Additional queries to filter matched events before they are processed.
     */
    readonly filters: pulumi.Output<outputs.SecurityMonitoringRuleFilter[] | undefined>;
    /**
     * Whether the notifications include the triggering group-by values in their title.
     */
    readonly hasExtendedTitle: pulumi.Output<boolean | undefined>;
    /**
     * Message for generated signals.
     */
    readonly message: pulumi.Output<string>;
    /**
     * The name of the rule.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Options on rules.
     */
    readonly options: pulumi.Output<outputs.SecurityMonitoringRuleOptions | undefined>;
    /**
     * Queries for selecting logs which are part of the rule.
     */
    readonly queries: pulumi.Output<outputs.SecurityMonitoringRuleQuery[] | undefined>;
    /**
     * Queries for selecting logs which are part of the rule.
     */
    readonly signalQueries: pulumi.Output<outputs.SecurityMonitoringRuleSignalQuery[] | undefined>;
    /**
     * Tags for generated signals.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * The rule type. Valid values are `logDetection`, `workloadSecurity`, `signalCorrelation`.
     */
    readonly type: pulumi.Output<string | undefined>;
    /**
     * Create a SecurityMonitoringRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityMonitoringRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SecurityMonitoringRule resources.
 */
export interface SecurityMonitoringRuleState {
    /**
     * Cases for generating signals.
     */
    cases?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleCase>[]>;
    /**
     * Whether the rule is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Additional queries to filter matched events before they are processed.
     */
    filters?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleFilter>[]>;
    /**
     * Whether the notifications include the triggering group-by values in their title.
     */
    hasExtendedTitle?: pulumi.Input<boolean>;
    /**
     * Message for generated signals.
     */
    message?: pulumi.Input<string>;
    /**
     * The name of the rule.
     */
    name?: pulumi.Input<string>;
    /**
     * Options on rules.
     */
    options?: pulumi.Input<inputs.SecurityMonitoringRuleOptions>;
    /**
     * Queries for selecting logs which are part of the rule.
     */
    queries?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleQuery>[]>;
    /**
     * Queries for selecting logs which are part of the rule.
     */
    signalQueries?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleSignalQuery>[]>;
    /**
     * Tags for generated signals.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The rule type. Valid values are `logDetection`, `workloadSecurity`, `signalCorrelation`.
     */
    type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a SecurityMonitoringRule resource.
 */
export interface SecurityMonitoringRuleArgs {
    /**
     * Cases for generating signals.
     */
    cases: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleCase>[]>;
    /**
     * Whether the rule is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Additional queries to filter matched events before they are processed.
     */
    filters?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleFilter>[]>;
    /**
     * Whether the notifications include the triggering group-by values in their title.
     */
    hasExtendedTitle?: pulumi.Input<boolean>;
    /**
     * Message for generated signals.
     */
    message: pulumi.Input<string>;
    /**
     * The name of the rule.
     */
    name: pulumi.Input<string>;
    /**
     * Options on rules.
     */
    options?: pulumi.Input<inputs.SecurityMonitoringRuleOptions>;
    /**
     * Queries for selecting logs which are part of the rule.
     */
    queries?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleQuery>[]>;
    /**
     * Queries for selecting logs which are part of the rule.
     */
    signalQueries?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringRuleSignalQuery>[]>;
    /**
     * Tags for generated signals.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The rule type. Valid values are `logDetection`, `workloadSecurity`, `signalCorrelation`.
     */
    type?: pulumi.Input<string>;
}
