import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog SensitiveDataScannerRule resource. This can be used to create and manage Datadog sensitive_data_scanner_rule.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Create new sensitive_data_scanner_rule resource in a sensitive_data_scanner_group
 * const mygroup = new datadog.SensitiveDataScannerGroup("mygroup", {
 *     name: "My new scanning group",
 *     description: "A relevant description",
 *     filter: {
 *         query: "service:my-service",
 *     },
 *     isEnabled: true,
 *     productLists: ["apm"],
 * });
 * const myrule = new datadog.SensitiveDataScannerRule("myrule", {
 *     name: "My new rule",
 *     description: "Another description",
 *     groupId: mygroup.id,
 *     excludedNamespaces: ["username"],
 *     isEnabled: true,
 *     pattern: "myregex",
 *     tags: ["sensitive_data:true"],
 *     textReplacement: {
 *         numberOfChars: 0,
 *         replacementString: "",
 *         type: "hash",
 *     },
 * });
 * const awsSp = datadog.getSensitiveDataScannerStandardPattern({
 *     filter: "AWS Access Key ID Scanner",
 * });
 * const mylibraryrule = new datadog.SensitiveDataScannerRule("mylibraryrule", {
 *     name: "My library rule",
 *     description: "A description",
 *     groupId: mygroup.id,
 *     standardPatternId: awsSp.then(awsSp => awsSp.id),
 *     excludedNamespaces: ["username"],
 *     isEnabled: true,
 *     tags: ["sensitive_data:true"],
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/sensitiveDataScannerRule:SensitiveDataScannerRule new_list ""
 * ```
 */
export declare class SensitiveDataScannerRule extends pulumi.CustomResource {
    /**
     * Get an existing SensitiveDataScannerRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SensitiveDataScannerRuleState, opts?: pulumi.CustomResourceOptions): SensitiveDataScannerRule;
    /**
     * Returns true if the given object is an instance of SensitiveDataScannerRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SensitiveDataScannerRule;
    /**
     * Description of the rule.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Attributes excluded from the scan. If namespaces is provided, it has to be a sub-path of the namespaces array.
     */
    readonly excludedNamespaces: pulumi.Output<string[] | undefined>;
    /**
     * Id of the scanning group the rule belongs to.
     */
    readonly groupId: pulumi.Output<string>;
    /**
     * Whether or not the rule is enabled.
     */
    readonly isEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Name of the rule.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Attributes included in the scan. If namespaces is empty or missing, all attributes except excludedNamespaces are scanned. If both are missing the whole event is scanned.
     */
    readonly namespaces: pulumi.Output<string[] | undefined>;
    /**
     * Not included if there is a relationship to a standard pattern.
     */
    readonly pattern: pulumi.Output<string | undefined>;
    /**
     * Id of the standard pattern the rule refers to. If provided, then pattern must not be provided.
     */
    readonly standardPatternId: pulumi.Output<string | undefined>;
    /**
     * List of tags.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * Object describing how the scanned event will be replaced. Defaults to `type: none`
     */
    readonly textReplacement: pulumi.Output<outputs.SensitiveDataScannerRuleTextReplacement | undefined>;
    /**
     * Create a SensitiveDataScannerRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SensitiveDataScannerRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SensitiveDataScannerRule resources.
 */
export interface SensitiveDataScannerRuleState {
    /**
     * Description of the rule.
     */
    description?: pulumi.Input<string>;
    /**
     * Attributes excluded from the scan. If namespaces is provided, it has to be a sub-path of the namespaces array.
     */
    excludedNamespaces?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Id of the scanning group the rule belongs to.
     */
    groupId?: pulumi.Input<string>;
    /**
     * Whether or not the rule is enabled.
     */
    isEnabled?: pulumi.Input<boolean>;
    /**
     * Name of the rule.
     */
    name?: pulumi.Input<string>;
    /**
     * Attributes included in the scan. If namespaces is empty or missing, all attributes except excludedNamespaces are scanned. If both are missing the whole event is scanned.
     */
    namespaces?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Not included if there is a relationship to a standard pattern.
     */
    pattern?: pulumi.Input<string>;
    /**
     * Id of the standard pattern the rule refers to. If provided, then pattern must not be provided.
     */
    standardPatternId?: pulumi.Input<string>;
    /**
     * List of tags.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Object describing how the scanned event will be replaced. Defaults to `type: none`
     */
    textReplacement?: pulumi.Input<inputs.SensitiveDataScannerRuleTextReplacement>;
}
/**
 * The set of arguments for constructing a SensitiveDataScannerRule resource.
 */
export interface SensitiveDataScannerRuleArgs {
    /**
     * Description of the rule.
     */
    description?: pulumi.Input<string>;
    /**
     * Attributes excluded from the scan. If namespaces is provided, it has to be a sub-path of the namespaces array.
     */
    excludedNamespaces?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Id of the scanning group the rule belongs to.
     */
    groupId: pulumi.Input<string>;
    /**
     * Whether or not the rule is enabled.
     */
    isEnabled?: pulumi.Input<boolean>;
    /**
     * Name of the rule.
     */
    name?: pulumi.Input<string>;
    /**
     * Attributes included in the scan. If namespaces is empty or missing, all attributes except excludedNamespaces are scanned. If both are missing the whole event is scanned.
     */
    namespaces?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Not included if there is a relationship to a standard pattern.
     */
    pattern?: pulumi.Input<string>;
    /**
     * Id of the standard pattern the rule refers to. If provided, then pattern must not be provided.
     */
    standardPatternId?: pulumi.Input<string>;
    /**
     * List of tags.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Object describing how the scanned event will be replaced. Defaults to `type: none`
     */
    textReplacement?: pulumi.Input<inputs.SensitiveDataScannerRuleTextReplacement>;
}
