import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog service level objective resource. This can be used to create and manage Datadog service level objectives.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Metric-Based SLO
 * // Create a new Datadog service level objective
 * const foo = new datadog.ServiceLevelObjective("foo", {
 *     description: "My custom metric SLO",
 *     name: "Example Metric SLO",
 *     query: {
 *         denominator: "sum:my.custom.count.metric{*}.as_count()",
 *         numerator: "sum:my.custom.count.metric{type:good_events}.as_count()",
 *     },
 *     tags: [
 *         "foo:bar",
 *         "baz",
 *     ],
 *     targetThreshold: 99.9,
 *     thresholds: [
 *         {
 *             target: 99.9,
 *             timeframe: "7d",
 *             warning: 99.99,
 *         },
 *         {
 *             target: 99.9,
 *             timeframe: "30d",
 *             warning: 99.99,
 *         },
 *     ],
 *     timeframe: "30d",
 *     type: "metric",
 *     warningThreshold: 99.99,
 * });
 * // Monitor-Based SLO
 * // Create a new Datadog service level objective
 * const bar = new datadog.ServiceLevelObjective("bar", {
 *     description: "My custom monitor SLO",
 *     monitorIds: [
 *         1,
 *         2,
 *         3,
 *     ],
 *     name: "Example Monitor SLO",
 *     tags: [
 *         "foo:bar",
 *         "baz",
 *     ],
 *     targetThreshold: 99.9,
 *     thresholds: [
 *         {
 *             target: 99.9,
 *             timeframe: "7d",
 *             warning: 99.99,
 *         },
 *         {
 *             target: 99.9,
 *             timeframe: "30d",
 *             warning: 99.99,
 *         },
 *     ],
 *     timeframe: "30d",
 *     type: "monitor",
 *     warningThreshold: 99.99,
 * });
 * ```
 *
 * ## Import
 *
 * Service Level Objectives can be imported using their string ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/serviceLevelObjective:ServiceLevelObjective baz 12345678901234567890123456789012
 * ```
 */
export declare class ServiceLevelObjective extends pulumi.CustomResource {
    /**
     * Get an existing ServiceLevelObjective resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceLevelObjectiveState, opts?: pulumi.CustomResourceOptions): ServiceLevelObjective;
    /**
     * Returns true if the given object is an instance of ServiceLevelObjective.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceLevelObjective;
    /**
     * A description of this service level objective.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A boolean indicating whether this monitor can be deleted even if it's referenced by other resources (for example, dashboards).
     */
    readonly forceDelete: pulumi.Output<boolean | undefined>;
    /**
     * A static set of groups to filter monitor-based SLOs
     */
    readonly groups: pulumi.Output<string[] | undefined>;
    /**
     * A static set of monitor IDs to use as part of the SLO
     */
    readonly monitorIds: pulumi.Output<number[] | undefined>;
    /**
     * Name of Datadog service level objective
     */
    readonly name: pulumi.Output<string>;
    /**
     * The metric query of good / total events
     */
    readonly query: pulumi.Output<outputs.ServiceLevelObjectiveQuery | undefined>;
    /**
     * A list of tags to associate with your service level objective. This can help you categorize and filter service level objectives in the service level objectives page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * The objective's target in `(0,100)`. This must match the corresponding thresholds of the primary time frame.
     */
    readonly targetThreshold: pulumi.Output<number>;
    /**
     * A list of thresholds and targets that define the service level objectives from the provided SLIs.
     */
    readonly thresholds: pulumi.Output<outputs.ServiceLevelObjectiveThreshold[]>;
    /**
     * The primary time frame for the objective. The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API documentation page. Valid values are `7d`, `30d`, `90d`, `custom`.
     */
    readonly timeframe: pulumi.Output<string>;
    /**
     * The type of the service level objective. The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API [documentation page](https://docs.datadoghq.com/api/v1/service-level-objectives/#create-a-slo-object). Valid values are `metric`, `monitor`.
     */
    readonly type: pulumi.Output<string>;
    /**
     * Whether or not to validate the SLO.
     */
    readonly validate: pulumi.Output<boolean | undefined>;
    /**
     * The objective's warning value in `(0,100)`. This must be greater than the target value and match the corresponding thresholds of the primary time frame.
     */
    readonly warningThreshold: pulumi.Output<number>;
    /**
     * Create a ServiceLevelObjective resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceLevelObjectiveArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceLevelObjective resources.
 */
export interface ServiceLevelObjectiveState {
    /**
     * A description of this service level objective.
     */
    description?: pulumi.Input<string>;
    /**
     * A boolean indicating whether this monitor can be deleted even if it's referenced by other resources (for example, dashboards).
     */
    forceDelete?: pulumi.Input<boolean>;
    /**
     * A static set of groups to filter monitor-based SLOs
     */
    groups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A static set of monitor IDs to use as part of the SLO
     */
    monitorIds?: pulumi.Input<pulumi.Input<number>[]>;
    /**
     * Name of Datadog service level objective
     */
    name?: pulumi.Input<string>;
    /**
     * The metric query of good / total events
     */
    query?: pulumi.Input<inputs.ServiceLevelObjectiveQuery>;
    /**
     * A list of tags to associate with your service level objective. This can help you categorize and filter service level objectives in the service level objectives page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The objective's target in `(0,100)`. This must match the corresponding thresholds of the primary time frame.
     */
    targetThreshold?: pulumi.Input<number>;
    /**
     * A list of thresholds and targets that define the service level objectives from the provided SLIs.
     */
    thresholds?: pulumi.Input<pulumi.Input<inputs.ServiceLevelObjectiveThreshold>[]>;
    /**
     * The primary time frame for the objective. The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API documentation page. Valid values are `7d`, `30d`, `90d`, `custom`.
     */
    timeframe?: pulumi.Input<string>;
    /**
     * The type of the service level objective. The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API [documentation page](https://docs.datadoghq.com/api/v1/service-level-objectives/#create-a-slo-object). Valid values are `metric`, `monitor`.
     */
    type?: pulumi.Input<string>;
    /**
     * Whether or not to validate the SLO.
     */
    validate?: pulumi.Input<boolean>;
    /**
     * The objective's warning value in `(0,100)`. This must be greater than the target value and match the corresponding thresholds of the primary time frame.
     */
    warningThreshold?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a ServiceLevelObjective resource.
 */
export interface ServiceLevelObjectiveArgs {
    /**
     * A description of this service level objective.
     */
    description?: pulumi.Input<string>;
    /**
     * A boolean indicating whether this monitor can be deleted even if it's referenced by other resources (for example, dashboards).
     */
    forceDelete?: pulumi.Input<boolean>;
    /**
     * A static set of groups to filter monitor-based SLOs
     */
    groups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A static set of monitor IDs to use as part of the SLO
     */
    monitorIds?: pulumi.Input<pulumi.Input<number>[]>;
    /**
     * Name of Datadog service level objective
     */
    name: pulumi.Input<string>;
    /**
     * The metric query of good / total events
     */
    query?: pulumi.Input<inputs.ServiceLevelObjectiveQuery>;
    /**
     * A list of tags to associate with your service level objective. This can help you categorize and filter service level objectives in the service level objectives page of the UI. Note: it's not currently possible to filter by these tags when querying via the API
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The objective's target in `(0,100)`. This must match the corresponding thresholds of the primary time frame.
     */
    targetThreshold?: pulumi.Input<number>;
    /**
     * A list of thresholds and targets that define the service level objectives from the provided SLIs.
     */
    thresholds: pulumi.Input<pulumi.Input<inputs.ServiceLevelObjectiveThreshold>[]>;
    /**
     * The primary time frame for the objective. The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API documentation page. Valid values are `7d`, `30d`, `90d`, `custom`.
     */
    timeframe?: pulumi.Input<string>;
    /**
     * The type of the service level objective. The mapping from these types to the types found in the Datadog Web UI can be found in the Datadog API [documentation page](https://docs.datadoghq.com/api/v1/service-level-objectives/#create-a-slo-object). Valid values are `metric`, `monitor`.
     */
    type: pulumi.Input<string>;
    /**
     * Whether or not to validate the SLO.
     */
    validate?: pulumi.Input<boolean>;
    /**
     * The objective's warning value in `(0,100)`. This must be greater than the target value and match the corresponding thresholds of the primary time frame.
     */
    warningThreshold?: pulumi.Input<number>;
}
