import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog synthetics global variable resource. This can be used to create and manage Datadog synthetics global variables.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const testVariable = new datadog.SyntheticsGlobalVariable("testVariable", {
 *     description: "Description of the variable",
 *     name: "EXAMPLE_VARIABLE",
 *     tags: [
 *         "foo:bar",
 *         "env:test",
 *     ],
 *     value: "variable-value",
 * });
 * ```
 *
 * ## Import
 *
 * Synthetics global variables can be imported using their string ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/syntheticsGlobalVariable:SyntheticsGlobalVariable fizz abcde123-fghi-456-jkl-mnopqrstuv
 * ```
 */
export declare class SyntheticsGlobalVariable extends pulumi.CustomResource {
    /**
     * Get an existing SyntheticsGlobalVariable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SyntheticsGlobalVariableState, opts?: pulumi.CustomResourceOptions): SyntheticsGlobalVariable;
    /**
     * Returns true if the given object is an instance of SyntheticsGlobalVariable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SyntheticsGlobalVariable;
    /**
     * Description of the global variable.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Synthetics global variable name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Additional options for the variable, such as a MFA token.
     */
    readonly options: pulumi.Output<outputs.SyntheticsGlobalVariableOptions | undefined>;
    /**
     * Id of the Synthetics test to use for a variable from test.
     */
    readonly parseTestId: pulumi.Output<string | undefined>;
    /**
     * ID of the Synthetics test to use a source of the global variable value.
     */
    readonly parseTestOptions: pulumi.Output<outputs.SyntheticsGlobalVariableParseTestOptions | undefined>;
    /**
     * A list of role identifiers to associate with the Synthetics global variable.
     */
    readonly restrictedRoles: pulumi.Output<string[] | undefined>;
    /**
     * If set to true, the value of the global variable is hidden. Defaults to `false`.
     */
    readonly secure: pulumi.Output<boolean | undefined>;
    /**
     * A list of tags to associate with your synthetics global variable.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * The value of the global variable.
     */
    readonly value: pulumi.Output<string>;
    /**
     * Create a SyntheticsGlobalVariable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SyntheticsGlobalVariableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SyntheticsGlobalVariable resources.
 */
export interface SyntheticsGlobalVariableState {
    /**
     * Description of the global variable.
     */
    description?: pulumi.Input<string>;
    /**
     * Synthetics global variable name.
     */
    name?: pulumi.Input<string>;
    /**
     * Additional options for the variable, such as a MFA token.
     */
    options?: pulumi.Input<inputs.SyntheticsGlobalVariableOptions>;
    /**
     * Id of the Synthetics test to use for a variable from test.
     */
    parseTestId?: pulumi.Input<string>;
    /**
     * ID of the Synthetics test to use a source of the global variable value.
     */
    parseTestOptions?: pulumi.Input<inputs.SyntheticsGlobalVariableParseTestOptions>;
    /**
     * A list of role identifiers to associate with the Synthetics global variable.
     */
    restrictedRoles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * If set to true, the value of the global variable is hidden. Defaults to `false`.
     */
    secure?: pulumi.Input<boolean>;
    /**
     * A list of tags to associate with your synthetics global variable.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The value of the global variable.
     */
    value?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a SyntheticsGlobalVariable resource.
 */
export interface SyntheticsGlobalVariableArgs {
    /**
     * Description of the global variable.
     */
    description?: pulumi.Input<string>;
    /**
     * Synthetics global variable name.
     */
    name: pulumi.Input<string>;
    /**
     * Additional options for the variable, such as a MFA token.
     */
    options?: pulumi.Input<inputs.SyntheticsGlobalVariableOptions>;
    /**
     * Id of the Synthetics test to use for a variable from test.
     */
    parseTestId?: pulumi.Input<string>;
    /**
     * ID of the Synthetics test to use a source of the global variable value.
     */
    parseTestOptions?: pulumi.Input<inputs.SyntheticsGlobalVariableParseTestOptions>;
    /**
     * A list of role identifiers to associate with the Synthetics global variable.
     */
    restrictedRoles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * If set to true, the value of the global variable is hidden. Defaults to `false`.
     */
    secure?: pulumi.Input<boolean>;
    /**
     * A list of tags to associate with your synthetics global variable.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The value of the global variable.
     */
    value: pulumi.Input<string>;
}
